@@ -4,7 +4,7 @@ var Cc = Components.classes;
 var Cr = Components.results;
 
 var jumlib = {};
-Components.utils.import("resource://mozmill/modules/jum.js", jumlib);
+Cu.import("resource://mozmill/modules/jum.js", jumlib);
 
 var topsrcDir;
 
