@@ -34,10 +34,6 @@ var windowListener = {
 
 function startup(params, reason) {
 try {
-    var commandLineHandlerPath = params.installPath.clone();
-    commandLineHandlerPath.append('content');
-    commandLineHandlerPath.append('command-line-handler.manifest');
-
     Cm.addBootstrappedManifestLocation(params.installPath);
 
     var uri = ios.newURI("chrome://unity/skin/browser.css", null, null);
@@ -49,48 +45,27 @@ try {
 
     resource.setSubstitution("unity", alias);
 
-    var chromelessUrlpolicyPath = params.installPath.clone();
-    chromelessUrlpolicyPath.append('content');
-    chromelessUrlpolicyPath.append('chromeless-urlpolicy.manifest');
-    Cm.QueryInterface(Ci.nsIComponentRegistrar).autoRegister(chromelessUrlpolicyPath);
-    Cm.QueryInterface(Ci.nsIComponentRegistrar).autoRegister(commandLineHandlerPath);
-
     Cu.import("resource://unity/observer.js");
 
     observer = new Observer();
     observer.activate();
 
     Cu.import("resource://unity/prefs.js");
-    Cu.import("resource://unity/chromeless.js");
 
     wm.addListener(windowListener);
 } catch (x) {dump(x);}
 }
 
 function shutdown(params, reason) {
-    Chromeless.deactivate();
-
     wm.removeListener(windowListener);
 
-    Cu.unload("resource://unity/chromeless.js");
     Cu.unload("resource://unity/prefs.js");
 
-    var manifest = params.installPath.clone();
-    manifest.append('content');
-    manifest.append('command-line-handler.manifest');
-
     observer.deactivate();
     observer = null;
 
     Cu.unload("resource://unity/observer.js");
 
-    Cm.QueryInterface(Ci.nsIComponentRegistrar).autoUnregister(manifest);
-
-    var chromelessUrlpolicyPath = params.installPath.clone();
-    chromelessUrlpolicyPath.append('content');
-    chromelessUrlpolicyPath.append('chromeless-urlpolicy.manifest');
-    Cm.QueryInterface(Ci.nsIComponentRegistrar).autoUnregister(chromelessUrlpolicyPath);
-
     resource.setSubstitution("unity", null);
 
     var uri = ios.newURI("chrome://unity/skin/browser.css", null, null);
