@@ -25,8 +25,12 @@ then
     exit 2
 fi
 
-echo "Generating unity-webapps.js from $GIR_FILE"
-xsltproc -novalid tools/gir-ctypes.xslt $GIR_FILE | perl tools/post-process.pl > content/unity-webapps.js
+# Disable temporarily the automatic generation of bindings to handle the small issue with
+# generated (but private) functions *_gen_* that have been removed from the exported symbols
+# in recent versions.
+
+# echo "Generating unity-webapps.js from $GIR_FILE"
+# xsltproc -novalid tools/gir-ctypes.xslt $GIR_FILE | perl tools/post-process.pl > content/unity-webapps.js
 
 zip -x build.sh -x COPYING -r unity.xpi *
 
